
      common /ZdedxAir/ stha, sthb, sthc, sthx0, sthx1, sthsa,
     *   wlg0, w0, betasq, tmax, norm, w0inMeV,
     *   Knckon, jdef

	real*8  stha, sthb, sthc, sthx0, sthx1, sthsa
	real*8  wlg0, w0, betasq, tmax, norm, w0inMeV
	integer jdef
        logical Knckon

